pub struct Context<'msg> {
pub actor: Option<&'msg str>,
pub span: Option<String>,
}Expand description
Context - message passing metadata used by wasmhost Actors and Capability Providers
Fields
actor: Option<&'msg str>Messages received by Context Provider will have actor set to the actor’s public key
span: Option<String>Span name/context for tracing. This is a placeholder for now